pro epoch_chk,index_in,lk_era=lk_era,era_no=era_no,debug=debug

;+
; NAME
;	epoch_chk
; PURPOSE
;	Returnd the dates (string) of the beginning and end of
;	the leak era corresponding to the input indes.
; CALLING SEQUENCE
;	epoch_chk,index_in,lk_era=lk_era,era_no=era_no,debug=debug
;	epoch_chk,index(0),lk_era=lk_era,lk_no=lk_no
; INPUT
;	index_in, SXT index or roadmap structure
; OPTIONAL KEYWORD INPUT
;	/debug causes the program to stop just before end
; KEYWORD OUTPUT
;	lk_era returns the beginning and end dates of the leak epoch.
;	era_no returns the leak-epoch number, i.e.,
;
;	   era_no           bounds of leak epoch
;	     0    30-AUG-91  10:30:00   13-NOV-92  18:00:00
;            1    13-NOV-92  18:00:00   16-AUG-95  08:04:20
;            2    16-AUG-95  08:04:20   24-AUG-96  07:00:00
;            3    24-AUG-96  07:00:00   24-JAN-98  00:00:00
;            4    24-JAN-98  00:00:00   30-JAN-99  23:17:00
;            5    30-JAN-99  23:17:00   12-MAR-99  02:00:00
;            6    12-MAR-99  02:00:00   20-APR-99  19:02:00
;	     7    20-APR-99  19:02:00   end of mission
;
; HISTORY
; 25-Oct-2002 LWA  Cribbed from mk_syn_sfc.pro.  Thanks, Phil.
; 27-OCT-2002 LWA  Added header and era_no
;-


;Test that all SFC being generated will be from the same
;filter failure epoch.
epoch_date  = gt_day(index_in(0),/str)
epoch_bound = [get_yo_dates(/launch),get_yo_dates(/entrance),ut_time(!stime)]
t_compare   = ssw_time_compare(epoch_bound, epoch_date, /later)
later     = where((t_compare eq 1), num_gd_later)
epoch0 = later(0)-1
epoch1 = epoch0+1

;Test that all index records are from the same epoch.
epoch_test = gt_day(index_in) ;TEST LIMITS!!!
temp_bound=intarr(n_elements(epoch_bound))
FOR i = 0,n_elements(temp_bound)-2  DO BEGIN
   x_tmp=where((epoch_test gt gt_day(epoch_bound(i))) $
      and (epoch_test lt gt_day(epoch_bound(i+1))),num_good)
   temp_bound(i) = num_good
ENDFOR
y_tmp = where(temp_bound GT 0, num_gt_zero)
IF (num_gt_zero GT 1) THEN BEGIN $
   MESSAGE, 'Index_in files must be from the SAME filter failure epoch.'
   RETURN
ENDIF

lk_era = [epoch_bound(epoch0),epoch_bound(epoch1)]
era_no = epoch0-1

if keyword_set(debug) then stop

end
